@@ -1,7 +1,7 @@
 package WebService::BaseClientRole;
 use Moo::Role;
 
-our $VERSION = '0.0007'; # VERSION
+our $VERSION = '0.0008'; # VERSION
 
 use HTTP::Request::Common qw(DELETE GET POST PUT);
 use JSON qw(decode_json encode_json);
@@ -63,6 +63,8 @@ around qw(delete get post put) => sub {
 
 sub req {
     my ($self, $req) = @_;
+    warn 'WebService::BaseClientRole has been DEPRECATED in favor of'
+        . ' WebService::Client.';
     $req->header(content_type => 'application/json');
     $self->_log_request($req);
     my $res = $self->ua->request($req);
@@ -105,7 +107,7 @@ sub log {
     $self->logger->DEBUG($msg);
 }
 
-# ABSTRACT: A base role for quickly and easily creating web service clients
+# ABSTRACT: [DEPRECATED] A base role for quickly and easily creating web service clients
 
 
 1;
@@ -118,14 +120,17 @@ __END__
 
 =head1 NAME
 
-WebService::BaseClientRole - A base role for quickly and easily creating web service clients
+WebService::BaseClientRole - [DEPRECATED] A base role for quickly and easily creating web service clients
 
 =head1 VERSION
 
-version 0.0007
+version 0.0008
 
 =head1 SYNOPSIS
 
+B<This module has been DEPRECATED in favor of> L<WebService::Client>.
+Please consider using that instead.
+
     {
         package WebService::Foo;
         use Moo;
@@ -167,6 +172,9 @@ version 0.0007
 
 =head1 DESCRIPTION
 
+B<This module has been DEPRECATED in favor of> L<WebService::Client>.
+Please consider using that instead.
+
 This module is a base role for quickly and easily creating web service clients.
 Every time I created a web service client, I noticed that I kept rewriting the
 same boilerplate code independent of the web service.
@@ -266,6 +274,10 @@ L<WebService::SmartyStreets>
 
 =item *
 
+L<WebService::Client>
+
+=item *
+
 L<Net::HTTP::API>
 
 =item *
